package com.goldenwater.slaj.eme.mapper;

import java.util.List;
import org.apache.ibatis.annotations.Mapper;
import com.goldenwater.slaj.eme.domain.BusiDrillEva;

/**
 * 应急演练评估 数据层
 */
@Mapper
public interface BusiDrillEvaMapper {

    /**
     * 查询应急演练评估
     * @param guid 查询条件
     * @return 应急演练评估
     */
    BusiDrillEva selectBusiDrillEvaByGuid(String guid);

    /**
     * 查询应急演练评估列表
     * @param busiDrillEva 查询条件
     * @return 应急演练评估集合
     */
    List<BusiDrillEva> selectBusiDrillEvaList(BusiDrillEva busiDrillEva);

    /**
     * 新增应急演练评估
     * @param busiDrillEva 应急演练评估
     * @return 影响行数
     */
    int insertBusiDrillEva(BusiDrillEva busiDrillEva);

    /**
     * 修改应急演练评估
     * @param busiDrillEva 应急演练评估
     * @return 影响行数
     */
    int updateBusiDrillEva(BusiDrillEva busiDrillEva);

    /**
     * 删除应急演练评估
     * @param guid 主键
     * @return 影响行数
     */
    int deleteBusiDrillEvaByGuid(String guid);

    /**
     * 批量删除应急演练评估
     * @param guids 主键数组
     * @return 影响行数
     */
    int deleteBusiDrillEvaByGuids(String[] guids);
}
